import React, { useState, useEffect } from 'react'

const aftercareSteps = [
  {
    day: 'Day 0',
    title: 'Immediately After Your Session',
    instructions: [
      'Keep the bandage on for 2-4 hours as instructed by your artist',
      'Remove bandage gently and wash hands thoroughly before touching tattoo',
      'Gently wash with lukewarm water and fragrance-free soap',
      'Pat dry with a clean paper towel (avoid regular towels)',
      'Apply a thin layer of recommended aftercare ointment',
      'Do not re-bandage unless specifically instructed'
    ],
    warning: 'Never use petroleum-based products like Vaseline'
  },
  {
    day: 'Days 1-3',
    title: 'Initial Healing Phase',
    instructions: [
      'Wash gently 2-3 times daily with lukewarm water',
      'Use fragrance-free, antibacterial soap',
      'Apply thin layer of aftercare ointment 3-4 times daily',
      'Expect some redness, swelling, and tenderness',
      'Avoid soaking (no baths, swimming, or hot tubs)',
      'Sleep on clean sheets, preferably on your back'
    ],
    warning: 'Contact your artist if you notice excessive redness, heat, or pus'
  },
  {
    day: 'Days 4-6',
    title: 'Peeling Begins',
    instructions: [
      'Tattoo may start to peel like a sunburn',
      'DO NOT pick, scratch, or peel the skin',
      'Switch to fragrance-free lotion instead of ointment',
      'Apply lotion 2-3 times daily or when skin feels tight',
      'Peeling and flaking is completely normal',
      'Colors may appear dull - this is temporary'
    ],
    warning: 'Picking at peeling skin can cause scarring and color loss'
  },
  {
    day: 'Days 7-10',
    title: 'Continued Peeling',
    instructions: [
      'Continue gentle washing and moisturizing routine',
      'Peeling should be subsiding',
      'Itching is normal - tap or slap gently instead of scratching',
      'Avoid tight clothing over the tattoo area',
      'Still no swimming, soaking, or excessive sun exposure',
      'Light exercise is okay, but avoid excessive sweating'
    ],
    warning: 'If itching is severe or accompanied by rash, consult your artist'
  },
  {
    day: 'Days 11-14',
    title: 'Final Healing Stage',
    instructions: [
      'Skin should look mostly healed on the surface',
      'Continue moisturizing daily',
      'You can resume normal activities gradually',
      'Swimming and soaking are still not recommended',
      'Colors should start returning to normal vibrancy',
      'Schedule touch-up appointment if needed (after 4-6 weeks)'
    ],
    warning: 'Full healing takes 4-6 weeks - be patient with the process'
  },
  {
    day: 'Week 3+',
    title: 'Long-term Care',
    instructions: [
      'Tattoo is healed but skin is still regenerating underneath',
      'Always use SPF 30+ sunscreen on healed tattoos',
      'Moisturize regularly to keep skin healthy',
      'Avoid excessive sun exposure to prevent fading',
      'Schedule touch-ups if needed after 6-8 weeks',
      'Enjoy your new tattoo!'
    ],
    warning: 'Sun damage is the #1 cause of tattoo fading'
  }
]

const recommendedProducts = [
  {
    category: 'Aftercare Ointments',
    products: [
      'Aquaphor Healing Ointment',
      'A&D Original Ointment',
      'Hustle Butter Deluxe',
      'After Inked Tattoo Aftercare Lotion'
    ]
  },
  {
    category: 'Gentle Cleansers',
    products: [
      'Cetaphil Gentle Skin Cleanser',
      'Neutrogena Ultra Gentle Daily Cleanser',
      'Dove Sensitive Skin Beauty Bar',
      'CeraVe Hydrating Cleanser'
    ]
  },
  {
    category: 'Moisturizers',
    products: [
      'Cetaphil Daily Facial Moisturizer',
      'CeraVe Daily Moisturizing Lotion',
      'Eucerin Daily Protection Face Lotion',
      'Aveeno Daily Moisturizing Lotion'
    ]
  },
  {
    category: 'Sunscreens',
    products: [
      'EltaMD UV Clear Broad-Spectrum SPF 46',
      'Neutrogena Ultra Sheer Dry-Touch SPF 30',
      'CeraVe Hydrating Mineral Sunscreen SPF 30',
      'La Roche-Posay Anthelios Melt-in Milk SPF 60'
    ]
  }
]

const dosDonts = {
  dos: [
    'Keep the tattoo clean and dry',
    'Wash your hands before touching the tattoo',
    'Use fragrance-free, gentle products',
    'Wear loose, breathable clothing',
    'Get plenty of rest and stay hydrated',
    'Follow your artist\'s specific instructions',
    'Contact your artist with any concerns',
    'Be patient with the healing process'
  ],
  donts: [
    'Don\'t pick, scratch, or peel the tattoo',
    'Don\'t soak in baths, pools, or hot tubs',
    'Don\'t expose to direct sunlight',
    'Don\'t use petroleum-based products',
    'Don\'t wear tight or abrasive clothing',
    'Don\'t exercise excessively for the first week',
    'Don\'t ignore signs of infection',
    'Don\'t rush the healing process'
  ]
}

function Aftercare() {
  const [isLoaded, setIsLoaded] = useState(false)
  const [activeStep, setActiveStep] = useState(0)

  useEffect(() => {
    setIsLoaded(true)
  }, [])

  const generatePDF = () => {
    // In a real implementation, you would use a library like jsPDF
    // For now, we'll create a simple text version
    let pdfContent = 'TATTOO AFTERCARE INSTRUCTIONS\n\n'
    
    aftercareSteps.forEach(step => {
      pdfContent += `${step.day.toUpperCase()}: ${step.title}\n`
      pdfContent += '\n'
      step.instructions.forEach(instruction => {
        pdfContent += `• ${instruction}\n`
      })
      pdfContent += `\nIMPORTANT: ${step.warning}\n\n`
      pdfContent += '---\n\n'
    })
    
    pdfContent += 'RECOMMENDED PRODUCTS\n\n'
    recommendedProducts.forEach(category => {
      pdfContent += `${category.category}:\n`
      category.products.forEach(product => {
        pdfContent += `• ${product}\n`
      })
      pdfContent += '\n'
    })
    
    // Create and download the file
    const blob = new Blob([pdfContent], { type: 'text/plain' })
    const url = window.URL.createObjectURL(blob)
    const a = document.createElement('a')
    a.href = url
    a.download = 'tattoo-aftercare-instructions.txt'
    document.body.appendChild(a)
    a.click()
    document.body.removeChild(a)
    window.URL.revokeObjectURL(url)
  }

  return (
    <div className="pt-16 lg:pt-20">
      {/* Header */}
      <section className="section-padding py-16 lg:py-24">
        <div className="container-max">
          <div className={`text-center transform transition-all duration-1000 ${
            isLoaded ? 'translate-y-0 opacity-100' : 'translate-y-8 opacity-0'
          }`}>
            <h1 className="text-4xl md:text-5xl lg:text-6xl font-serif font-bold mb-6">
              Tattoo Aftercare Guide
            </h1>
            <p className="text-lg md:text-xl text-gray-600 max-w-3xl mx-auto mb-8">
              Proper aftercare is essential for optimal healing and long-lasting results. 
              Follow these instructions carefully to ensure your tattoo heals beautifully.
            </p>
            <button
              onClick={generatePDF}
              className="btn-primary inline-flex items-center space-x-2"
            >
              <svg className="w-5 h-5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 10v6m0 0l-3-3m3 3l3-3m2 8H7a2 2 0 01-2-2V5a2 2 0 012-2h5.586a1 1 0 01.707.293l5.414 5.414a1 1 0 01.293.707V19a2 2 0 01-2 2z" />
              </svg>
              <span>Download PDF Guide</span>
            </button>
          </div>
        </div>
      </section>

      {/* Timeline Steps */}
      <section className="section-padding pb-16">
        <div className="container-max">
          <div className="max-w-4xl mx-auto">
            <h2 className="text-3xl font-serif font-bold text-center mb-12">
              Healing Timeline
            </h2>
            
            {/* Timeline Navigation */}
            <div className="flex flex-wrap justify-center gap-2 mb-12">
              {aftercareSteps.map((step, index) => (
                <button
                  key={index}
                  onClick={() => setActiveStep(index)}
                  className={`px-4 py-2 rounded-lg text-sm font-medium transition-colors duration-300 ${
                    activeStep === index
                      ? 'bg-black text-white'
                      : 'bg-gray-100 text-gray-600 hover:bg-gray-200'
                  }`}
                >
                  {step.day}
                </button>
              ))}
            </div>
            
            {/* Active Step Content */}
            <div className="bg-white border border-gray-200 rounded-xl p-8 shadow-sm">
              <div className="flex items-center mb-6">
                <div className="w-12 h-12 bg-black text-white rounded-full flex items-center justify-center font-bold mr-4">
                  {activeStep + 1}
                </div>
                <div>
                  <h3 className="text-xl font-serif font-bold">
                    {aftercareSteps[activeStep].title}
                  </h3>
                  <p className="text-gray-600">{aftercareSteps[activeStep].day}</p>
                </div>
              </div>
              
              <div className="space-y-4 mb-6">
                {aftercareSteps[activeStep].instructions.map((instruction, index) => (
                  <div key={index} className="flex items-start space-x-3">
                    <div className="w-2 h-2 bg-accent rounded-full mt-2 flex-shrink-0" />
                    <p className="text-gray-700">{instruction}</p>
                  </div>
                ))}
              </div>
              
              <div className="bg-red-50 border border-red-200 rounded-lg p-4">
                <div className="flex items-start space-x-3">
                  <svg className="w-5 h-5 text-red-500 mt-0.5 flex-shrink-0" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 9v2m0 4h.01m-6.938 4h13.856c1.54 0 2.502-1.667 1.732-2.5L13.732 4c-.77-.833-1.964-.833-2.732 0L3.732 16.5c-.77.833.192 2.5 1.732 2.5z" />
                  </svg>
                  <div>
                    <p className="font-medium text-red-800">Important Warning</p>
                    <p className="text-red-700 text-sm">{aftercareSteps[activeStep].warning}</p>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Do's and Don'ts */}
      <section className="section-padding py-16 bg-gray-50">
        <div className="container-max">
          <div className="max-w-6xl mx-auto">
            <h2 className="text-3xl font-serif font-bold text-center mb-12">
              Essential Do's and Don'ts
            </h2>
            
            <div className="grid grid-cols-1 lg:grid-cols-2 gap-8">
              {/* Do's */}
              <div className="bg-green-50 border border-green-200 rounded-xl p-8">
                <div className="flex items-center mb-6">
                  <div className="w-10 h-10 bg-green-500 text-white rounded-full flex items-center justify-center mr-4">
                    <svg className="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                      <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                    </svg>
                  </div>
                  <h3 className="text-xl font-serif font-bold text-green-800">DO</h3>
                </div>
                <div className="space-y-3">
                  {dosDonts.dos.map((item, index) => (
                    <div key={index} className="flex items-start space-x-3">
                      <div className="w-2 h-2 bg-green-500 rounded-full mt-2 flex-shrink-0" />
                      <p className="text-green-700">{item}</p>
                    </div>
                  ))}
                </div>
              </div>
              
              {/* Don'ts */}
              <div className="bg-red-50 border border-red-200 rounded-xl p-8">
                <div className="flex items-center mb-6">
                  <div className="w-10 h-10 bg-red-500 text-white rounded-full flex items-center justify-center mr-4">
                    <svg className="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                      <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
                    </svg>
                  </div>
                  <h3 className="text-xl font-serif font-bold text-red-800">DON'T</h3>
                </div>
                <div className="space-y-3">
                  {dosDonts.donts.map((item, index) => (
                    <div key={index} className="flex items-start space-x-3">
                      <div className="w-2 h-2 bg-red-500 rounded-full mt-2 flex-shrink-0" />
                      <p className="text-red-700">{item}</p>
                    </div>
                  ))}
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Recommended Products */}
      <section className="section-padding py-16">
        <div className="container-max">
          <div className="max-w-6xl mx-auto">
            <h2 className="text-3xl font-serif font-bold text-center mb-12">
              Recommended Products
            </h2>
            
            <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-8">
              {recommendedProducts.map((category, index) => (
                <div key={index} className="bg-white border border-gray-200 rounded-xl p-6">
                  <h3 className="text-lg font-serif font-bold mb-4">{category.category}</h3>
                  <div className="space-y-2">
                    {category.products.map((product, productIndex) => (
                      <div key={productIndex} className="flex items-start space-x-2">
                        <div className="w-1.5 h-1.5 bg-accent rounded-full mt-2 flex-shrink-0" />
                        <p className="text-sm text-gray-700">{product}</p>
                      </div>
                    ))}
                  </div>
                </div>
              ))}
            </div>
            
            <div className="text-center mt-8">
              <p className="text-gray-600 mb-4">
                These are general recommendations. Always follow your artist's specific product suggestions.
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* Emergency Contact */}
      <section className="section-padding py-16 bg-gray-900 text-white">
        <div className="container-max">
          <div className="max-w-4xl mx-auto text-center">
            <h2 className="text-3xl font-serif font-bold mb-6">
              When to Seek Help
            </h2>
            <p className="text-lg text-gray-300 mb-8">
              Contact your artist or a healthcare professional if you experience:
            </p>
            
            <div className="grid grid-cols-1 md:grid-cols-2 gap-6 mb-8">
              <div className="bg-gray-800 rounded-lg p-6">
                <h3 className="font-semibold mb-3">Signs of Infection</h3>
                <ul className="text-sm text-gray-300 space-y-1">
                  <li>• Excessive redness or heat</li>
                  <li>• Pus or unusual discharge</li>
                  <li>• Red streaking from the tattoo</li>
                  <li>• Fever or chills</li>
                </ul>
              </div>
              
              <div className="bg-gray-800 rounded-lg p-6">
                <h3 className="font-semibold mb-3">Allergic Reactions</h3>
                <ul className="text-sm text-gray-300 space-y-1">
                  <li>• Severe itching or rash</li>
                  <li>• Raised bumps or hives</li>
                  <li>• Unusual swelling</li>
                  <li>• Difficulty breathing</li>
                </ul>
              </div>
            </div>
            
            <div className="bg-red-600 rounded-lg p-6">
              <h3 className="font-semibold mb-2">Emergency Contact</h3>
              <p className="text-sm">
                For urgent concerns: Call (555) 123-4567 or visit your nearest emergency room
              </p>
            </div>
          </div>
        </div>
      </section>
    </div>
  )
}

export default Aftercare